@@ -34,7 +34,7 @@ use experimental qw( lexical_subs postderef signatures );
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.3.0';
+our $VERSION = 'v0.4.0';
 
 sub mvp_multivalue_args { qw( regions sections ) }
 
@@ -321,12 +321,12 @@ sub _generate_raw_pod($self) {
         if ( Pod::Elemental::Selectors::s_command( head1 => $found ) ) {
             my $heading = fc( $found->content );
             next if $sections->exists($heading);
+            unshift @children, $found unless $heading =~ /\A(?:append|prepend):/;
             $sections->set( $heading => \@children );
         }
     }
 
     my sub _get_section($heading) {
-
         if ( my $pod = $sections->get( fc $heading ) ) {
             return $pod->@*;
         }
@@ -382,7 +382,7 @@ sub _fake_weaver_section( $self, $class, $args = { } ) {
 
     my $weaver  = Pod::Weaver->new_with_default_config;
     my $section = $class->new( plugin_name => ref($self), weaver => $weaver, logger => $zilla->logger );
-    $section->weave_section( $doc, { zilla => $zilla, $args->%* } );
+    $section->weave_section( $doc, { zilla => $zilla, filename => $zilla->main_module->name, $args->%* } );
 
     return $doc->children->@*;
 }
@@ -401,7 +401,6 @@ sub _generate_pod_for_requirements($self) {
     return $self->_fake_weaver_section(
         "Pod::Weaver::Section::Requirements",
         {
-            filename     => $file->name,
             ppi_document => $self->ppi_document_for_file($file),
         }
     );
@@ -433,7 +432,7 @@ Dist::Zilla::Plugin::UsefulReadme - generate a README file with the useful bits
 
 =head1 VERSION
 
-version v0.3.0
+version v0.4.0
 
 =head1 SYNOPSIS
 
