@@ -14,42 +14,49 @@ use Pod::Elemental::Element::Nested;
 use Pod::Elemental::Element::Pod5::Command;
 use Pod::Elemental::Element::Pod5::Ordinary;
 use Pod::Elemental::Element::Pod5::Region;
-use Types::Common qw( NonEmptySimpleStr SimpleStr );
+use Types::Common qw( Bool NonEmptySimpleStr SimpleStr );
 
 use experimental qw( lexical_subs postderef signatures );
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.3.0';
+our $VERSION = 'v0.4.0';
 
 
 has header => (
-    is      => 'lazy',
+    is      => 'rw',
     isa     => NonEmptySimpleStr,
     default => 'RECENT CHANGES',
 );
 
 
 has changelog => (
-    is      => 'lazy',
+    is      => 'rw',
     isa     => NonEmptySimpleStr,
     default => 'Changes',
 );
 
 
 has version => (
-    is      => 'lazy',
+    is      => 'rw',
     isa     => SimpleStr,
     default => '',
 );
 
 
 has region => (
-    is      => 'lazy',
+    is      => 'rw',
     isa     => SimpleStr,
     default => '',
 );
 
+
+has all_modules => (
+    is      => 'rw',
+    isa     => Bool,
+    default => 0,
+);
+
 sub weave_section( $self, $document, $input ) {
 
     my $zilla = $input->{zilla};
@@ -59,6 +66,10 @@ sub weave_section( $self, $document, $input ) {
         return;
     }
 
+    if ( my $stash = $zilla ? $zilla->stash_named('%PodWeaver') : undef ) {
+        $stash->merge_stashed_config($self);
+    }
+
     my $file = first { $_->name eq $self->changelog } $zilla->files->@* or return;
 
     my $version = $self->version || ( $input->{version} // $zilla->version );
@@ -166,7 +177,7 @@ Pod::Weaver::Section::RecentChanges - generate POD with the recent changes
 
 =head1 VERSION
 
-version v0.3.0
+version v0.4.0
 
 =head1 SYNOPSIS
 
@@ -177,6 +188,14 @@ In the F<weaver.ini>
     changelog = Changes
     region    = :readme
 
+Or in the F<dist.ini> for L<Dist::Zilla>:
+
+    [PodWeaver]
+    [%PodWeaver]
+    RecentChanges.header    = RECENT CHANGES
+    RecentChanges.changelog = Changes
+    RecentChanges.region    = :readme
+
 =head1 DESCRIPTION
 
 This is a L<Pod::Weaver> plugin to add a section with the changelog entries for the current version.
@@ -208,6 +227,12 @@ When set to a non-empty string, the section will be embedded in a POD region, e.
 
 to make the region available for L<Dist::Zilla::Plugin::UsefulReadme> or L<Pod::Readme>.
 
+=head2 all_modules
+
+When true, this section will be added to all modules in the distribution, and not just the main module.
+
+When false (default), this section will only be added to the main module.
+
 =for Pod::Coverage weave_section
 
 =head1 SEE ALSO
